==> firebase_app_check_web-0.0.5%2B11.tar.gz: CHANGELOG.md <==
## 0.0.5+11

 - Update a dependency to the latest release.

## 0.0.5+10

 - Update a dependency to the latest release.

## 0.0.5+9

 - Update a dependency to the latest release.

## 0.0.5+8

 - Update a dependency to the latest release.

## 0.0.5+7

 - **FIX**: update all Dart SDK version constraints to Dart >= 2.16.0 (#8184). ([df4a5bab](https://github.com/FirebaseExtended/flutterfire/commit/df4a5bab3c029399b4f257a5dd658d302efe3908))

## 0.0.5+6

 - Update a dependency to the latest release.

## 0.0.5+5

 - Update a dependency to the latest release.

## 0.0.5+4

 - Update a dependency to the latest release.

## 0.0.5+3

 - Update a dependency to the latest release.

## 0.0.5+2

 - Update a dependency to the latest release.

## 0.0.5+1

 - Update a dependency to the latest release.

## 0.0.5

 - **FEAT**: add token apis and documentation (#7419).

## 0.0.4

 - **FEAT**: add token apis and documentation (#7419).

## 0.0.3+1

 - Update a dependency to the latest release.

## 0.0.3

 - **FEAT**: automatically inject Firebase JS SDKs (#7359).

## 0.0.2

 - **FEAT**: support initializing default `FirebaseApp` instances from Dart (#6549).

## 0.0.1+8

 - Update a dependency to the latest release.

## 0.0.1+7

 - Update a dependency to the latest release.

## 0.0.1+6

 - Update a dependency to the latest release.

## 0.0.1+5

 - Update a dependency to the latest release.

## 0.0.1+4

 - Update a dependency to the latest release.

## 0.0.1+3

 - Update a dependency to the latest release.

## 0.0.1+2

 - Update a dependency to the latest release.

## 0.0.1+1

 - Update a dependency to the latest release.

# 0.0.1

 - Initial release.

==> firebase_app_check_web-0.0.7%2B11.tar.gz: CHANGELOG.md <==
## 0.0.7+11

 - Update a dependency to the latest release.

## 0.0.7+10

 - Update a dependency to the latest release.

## 0.0.7+9

 - Update a dependency to the latest release.

## 0.0.7+8

 - Update a dependency to the latest release.

## 0.0.7+7

 - Update a dependency to the latest release.

## 0.0.7+6

 - Update a dependency to the latest release.

## 0.0.7+5

 - Update a dependency to the latest release.

## 0.0.7+4

 - Update a dependency to the latest release.

## 0.0.7+3

 - Update a dependency to the latest release.

## 0.0.7+2

 - Update a dependency to the latest release.

## 0.0.7+1

 - Update a dependency to the latest release.

## 0.0.7

 - **FEAT**: provide `androidDebugProvider` boolean for android debug provider & update app check example app ([#9412](https://github.com/firebase/flutterfire/issues/9412)). ([f1f26748](https://github.com/firebase/flutterfire/commit/f1f26748615c7c9d406e1d3d605e2987e1134ee7))

## 0.0.6+6

 - Update a dependency to the latest release.

## 0.0.6+5

 - Update a dependency to the latest release.

## 0.0.6+4

 - Update a dependency to the latest release.

## 0.0.6+3

 - Update a dependency to the latest release.

## 0.0.6+2

 - Update a dependency to the latest release.

## 0.0.6+1

 - Update a dependency to the latest release.

## 0.0.6

 - **FEAT**: upgrade to support v9.8.1 Firebase JS SDK ([#8235](https://github.com/firebase/flutterfire/issues/8235)). ([4b417af5](https://github.com/firebase/flutterfire/commit/4b417af574bb8a32ca8e4b3ab2ff253a22be9903))

## 0.0.5+16

 - **FIX**: bump `firebase_core_platform_interface` version to fix previous release. ([bea70ea5](https://github.com/firebase/flutterfire/commit/bea70ea5cbbb62cbfd2a7a74ae3a07cb12b3ee5a))

## 0.0.5+15

 - Update a dependency to the latest release.

## 0.0.5+14

 - **REFACTOR**: use "firebase" instead of "FirebaseExtended" as organisation in all links for this repository (#8791). ([d90b8357](https://github.com/firebase/flutterfire/commit/d90b8357db01d65e753021358668f0b129713e6b))

## 0.0.5+13

 - Update a dependency to the latest release.

## 0.0.5+12

 - Update a dependency to the latest release.

## 0.0.5+11

 - Update a dependency to the latest release.

## 0.0.5+10

 - Update a dependency to the latest release.

## 0.0.5+9

 - Update a dependency to the latest release.

## 0.0.5+8

 - Update a dependency to the latest release.

## 0.0.5+7

 - **FIX**: update all Dart SDK version constraints to Dart >= 2.16.0 (#8184). ([df4a5bab](https://github.com/firebase/flutterfire/commit/df4a5bab3c029399b4f257a5dd658d302efe3908))

## 0.0.5+6

 - Update a dependency to the latest release.

## 0.0.5+5

 - Update a dependency to the latest release.

## 0.0.5+4

 - Update a dependency to the latest release.

## 0.0.5+3

 - Update a dependency to the latest release.

## 0.0.5+2

 - Update a dependency to the latest release.

## 0.0.5+1

 - Update a dependency to the latest release.

## 0.0.5

 - **FEAT**: add token apis and documentation (#7419).

## 0.0.4

 - **FEAT**: add token apis and documentation (#7419).

## 0.0.3+1

 - Update a dependency to the latest release.

## 0.0.3

 - **FEAT**: automatically inject Firebase JS SDKs (#7359).

## 0.0.2

 - **FEAT**: support initializing default `FirebaseApp` instances from Dart (#6549).

## 0.0.1+8

 - Update a dependency to the latest release.

## 0.0.1+7

 - Update a dependency to the latest release.

## 0.0.1+6

 - Update a dependency to the latest release.

## 0.0.1+5

 - Update a dependency to the latest release.

## 0.0.1+4

 - Update a dependency to the latest release.

## 0.0.1+3

 - Update a dependency to the latest release.

## 0.0.1+2

 - Update a dependency to the latest release.

## 0.0.1+1

 - Update a dependency to the latest release.

# 0.0.1

 - Initial release.
